#[repr(u32)]pub enum WinchActions {
WINCH_RELAXED = 0,
WINCH_RELATIVE_LENGTH_CONTROL = 1,
WINCH_RATE_CONTROL = 2,
WINCH_LOCK = 3,
WINCH_DELIVER = 4,
WINCH_HOLD = 5,
WINCH_RETRACT = 6,
WINCH_LOAD_LINE = 7,
WINCH_ABANDON_LINE = 8,
WINCH_LOAD_PAYLOAD = 9,
}dialect-python_array_test only.Expand description
Winch actions.
Variants
WINCH_RELAXED = 0
Allow motor to freewheel.
WINCH_RELATIVE_LENGTH_CONTROL = 1
Wind or unwind specified length of line, optionally using specified rate.
WINCH_RATE_CONTROL = 2
Wind or unwind line at specified rate.
WINCH_LOCK = 3
Perform the locking sequence to relieve motor while in the fully retracted position. Only action and instance command parameters are used, others are ignored.
WINCH_DELIVER = 4
Sequence of drop, slow down, touch down, reel up, lock. Only action and instance command parameters are used, others are ignored.
WINCH_HOLD = 5
Engage motor and hold current position. Only action and instance command parameters are used, others are ignored.
WINCH_RETRACT = 6
Return the reel to the fully retracted position. Only action and instance command parameters are used, others are ignored.
WINCH_LOAD_LINE = 7
Load the reel with line. The winch will calculate the total loaded length and stop when the tension exceeds a threshold. Only action and instance command parameters are used, others are ignored.
WINCH_ABANDON_LINE = 8
Spool out the entire length of the line. Only action and instance command parameters are used, others are ignored.
WINCH_LOAD_PAYLOAD = 9
Spools out just enough to present the hook to the user to load the payload. Only action and instance command parameters are used, others are ignored
Implementations
Sourceimpl WinchActions
impl WinchActions