pub struct AUTOPILOT_STATE_FOR_GIMBAL_DEVICE_DATA {Show 13 fields
pub time_boot_us: u64,
pub q: [f32; 4],
pub q_estimated_delay_us: u32,
pub vx: f32,
pub vy: f32,
pub vz: f32,
pub v_estimated_delay_us: u32,
pub feed_forward_angular_velocity_z: f32,
pub estimator_status: EstimatorStatusFlags,
pub target_system: u8,
pub target_component: u8,
pub landed_state: MavLandedState,
pub angular_velocity_z: f32,
}dialect-python_array_test only.Expand description
Low level message containing autopilot state relevant for a gimbal device. This message is to be sent from the autopilot to the gimbal device component. The data of this message are for the gimbal device’s estimator corrections, in particular horizon compensation, as well as indicates autopilot control intentions, e.g. feed forward angular control in the z-axis.
ID: 286
Fields
time_boot_us: u64Timestamp (time since system boot).
q: [f32; 4]Quaternion components of autopilot attitude: w, x, y, z (1 0 0 0 is the null-rotation, Hamilton convention).
q_estimated_delay_us: u32Estimated delay of the attitude data. 0 if unknown.
vx: f32X Speed in NED (North, East, Down). NAN if unknown.
vy: f32Y Speed in NED (North, East, Down). NAN if unknown.
vz: f32Z Speed in NED (North, East, Down). NAN if unknown.
v_estimated_delay_us: u32Estimated delay of the speed data. 0 if unknown.
feed_forward_angular_velocity_z: f32Feed forward Z component of angular velocity (positive: yawing to the right). NaN to be ignored. This is to indicate if the autopilot is actively yawing.
estimator_status: EstimatorStatusFlagsBitmap indicating which estimator outputs are valid.
target_system: u8System ID
target_component: u8Component ID
landed_state: MavLandedStateThe landed state. Is set to MAV_LANDED_STATE_UNDEFINED if landed state is unknown.
angular_velocity_z: f32Z component of angular velocity in NED (North, East, Down). NaN if unknown.
Implementations