pub struct BATTERY_STATUS_DATA {Show 14 fields
pub current_consumed: i32,
pub energy_consumed: i32,
pub temperature: i16,
pub voltages: [u16; 10],
pub current_battery: i16,
pub id: u8,
pub battery_function: MavBatteryFunction,
pub mavtype: MavBatteryType,
pub battery_remaining: i8,
pub time_remaining: i32,
pub charge_state: MavBatteryChargeState,
pub voltages_ext: [u16; 4],
pub mode: MavBatteryMode,
pub fault_bitmask: MavBatteryFault,
}dialect-python_array_test only.Expand description
Battery information. Updates GCS with flight controller battery status. Smart batteries also use this message, but may additionally send BATTERY_INFO.
ID: 147
Fields
current_consumed: i32Consumed charge, -1: autopilot does not provide consumption estimate
energy_consumed: i32Consumed energy, -1: autopilot does not provide energy consumption estimate
temperature: i16Temperature of the battery. INT16_MAX for unknown temperature.
voltages: [u16; 10]Battery voltage of cells 1 to 10 (see voltages_ext for cells 11-14). Cells in this field above the valid cell count for this battery should have the UINT16_MAX value. If individual cell voltages are unknown or not measured for this battery, then the overall battery voltage should be filled in cell 0, with all others set to UINT16_MAX. If the voltage of the battery is greater than (UINT16_MAX - 1), then cell 0 should be set to (UINT16_MAX - 1), and cell 1 to the remaining voltage. This can be extended to multiple cells if the total voltage is greater than 2 * (UINT16_MAX - 1).
current_battery: i16Battery current, -1: autopilot does not measure the current
id: u8Battery ID
battery_function: MavBatteryFunctionFunction of the battery
mavtype: MavBatteryTypeType (chemistry) of the battery
battery_remaining: i8Remaining battery energy. Values: [0-100], -1: autopilot does not estimate the remaining battery.
time_remaining: i32Remaining battery time, 0: autopilot does not provide remaining battery time estimate
charge_state: MavBatteryChargeStateState for extent of discharge, provided by autopilot for warning or external reactions
voltages_ext: [u16; 4]Battery voltages for cells 11 to 14. Cells above the valid cell count for this battery should have a value of 0, where zero indicates not supported (note, this is different than for the voltages field and allows empty byte truncation). If the measured value is 0 then 1 should be sent instead.
mode: MavBatteryModeBattery mode. Default (0) is that battery mode reporting is not supported or battery is in normal-use mode.
fault_bitmask: MavBatteryFaultFault/health indications. These should be set when charge_state is MAV_BATTERY_CHARGE_STATE_FAILED or MAV_BATTERY_CHARGE_STATE_UNHEALTHY (if not, fault reporting is not supported).
Implementations