pub struct MISSION_ITEM_DATA {}MISSION_ITEM_INT (Deprecated since 2020-06)dialect-python_array_test only.Expand description
Message encoding a mission item. This message is emitted to announce the presence of a mission item and to set a mission item on the system. The mission item can be either in x, y, z meters (type: LOCAL) or x:lat, y:lon, z:altitude. Local frame is Z-down, right handed (NED), global frame is Z-up, right handed (ENU). NaN may be used to indicate an optional/default value (e.g. to use the system’s current latitude or yaw rather than a specific value). See also https://mavlink.io/en/services/mission.html.
ID: 39
Fields
param1: f32MISSION_ITEM_INT (Deprecated since 2020-06)PARAM1, see MAV_CMD enum
param2: f32MISSION_ITEM_INT (Deprecated since 2020-06)PARAM2, see MAV_CMD enum
param3: f32MISSION_ITEM_INT (Deprecated since 2020-06)PARAM3, see MAV_CMD enum
param4: f32MISSION_ITEM_INT (Deprecated since 2020-06)PARAM4, see MAV_CMD enum
x: f32MISSION_ITEM_INT (Deprecated since 2020-06)PARAM5 / local: X coordinate, global: latitude
y: f32MISSION_ITEM_INT (Deprecated since 2020-06)PARAM6 / local: Y coordinate, global: longitude
z: f32MISSION_ITEM_INT (Deprecated since 2020-06)PARAM7 / local: Z coordinate, global: altitude (relative or absolute, depending on frame).
seq: u16MISSION_ITEM_INT (Deprecated since 2020-06)Sequence
command: MavCmdMISSION_ITEM_INT (Deprecated since 2020-06)The scheduled action for the waypoint.
target_system: u8MISSION_ITEM_INT (Deprecated since 2020-06)System ID
target_component: u8MISSION_ITEM_INT (Deprecated since 2020-06)Component ID
frame: MavFrameMISSION_ITEM_INT (Deprecated since 2020-06)The coordinate system of the waypoint.
current: u8MISSION_ITEM_INT (Deprecated since 2020-06)false:0, true:1
autocontinue: u8MISSION_ITEM_INT (Deprecated since 2020-06)Autocontinue to next waypoint. 0: false, 1: true. Set false to pause mission after the item completes.
mission_type: MavMissionTypeMISSION_ITEM_INT (Deprecated since 2020-06)Mission type.
Implementations