pub struct MISSION_REQUEST_DATA {
pub seq: u16,
pub target_system: u8,
pub target_component: u8,
pub mission_type: MavMissionType,
}๐Deprecated: A system that gets this request should respond with MISSION_ITEM_INT (as though MISSION_REQUEST_INT was received). See
MISSION_REQUEST_INT (Deprecated since 2020-06)Available on crate feature
dialect-python_array_test only.Expand description
Request the information of the mission item with the sequence number seq. The response of the system to this message should be a MISSION_ITEM message. https://mavlink.io/en/services/mission.html.
ID: 40
Fields
seq: u16๐Deprecated: A system that gets this request should respond with MISSION_ITEM_INT (as though MISSION_REQUEST_INT was received). See
MISSION_REQUEST_INT (Deprecated since 2020-06)Sequence
target_system: u8๐Deprecated: A system that gets this request should respond with MISSION_ITEM_INT (as though MISSION_REQUEST_INT was received). See
MISSION_REQUEST_INT (Deprecated since 2020-06)System ID
target_component: u8๐Deprecated: A system that gets this request should respond with MISSION_ITEM_INT (as though MISSION_REQUEST_INT was received). See
MISSION_REQUEST_INT (Deprecated since 2020-06)Component ID
mission_type: MavMissionType๐Deprecated: A system that gets this request should respond with MISSION_ITEM_INT (as though MISSION_REQUEST_INT was received). See
MISSION_REQUEST_INT (Deprecated since 2020-06)Mission type.
Implementations