pub struct PARAM_MAP_RC_DATA {
pub param_value0: f32,
pub scale: f32,
pub param_value_min: f32,
pub param_value_max: f32,
pub param_index: i16,
pub target_system: u8,
pub target_component: u8,
pub param_id: CharArray<16>,
pub parameter_rc_channel_index: u8,
}dialect-python_array_test only.Expand description
Bind a RC channel to a parameter. The parameter should change according to the RC channel value.
ID: 50
Fields
param_value0: f32Initial parameter value
scale: f32Scale, maps the RC range [-1, 1] to a parameter value
param_value_min: f32Minimum param value. The protocol does not define if this overwrites an onboard minimum value. (Depends on implementation)
param_value_max: f32Maximum param value. The protocol does not define if this overwrites an onboard maximum value. (Depends on implementation)
param_index: i16Parameter index. Send -1 to use the param ID field as identifier (else the param id will be ignored), send -2 to disable any existing map for this rc_channel_index.
target_system: u8System ID
target_component: u8Component ID
param_id: CharArray<16>Onboard parameter id, terminated by NULL if the length is less than 16 human-readable chars and WITHOUT null termination (NULL) byte if the length is exactly 16 chars - applications have to provide 16+1 bytes storage if the ID is stored as string
parameter_rc_channel_index: u8Index of parameter RC channel. Not equal to the RC channel id. Typically corresponds to a potentiometer-knob on the RC.
Implementations