pub struct PING_DATA {
pub time_usec: u64,
pub seq: u32,
pub target_system: u8,
pub target_component: u8,
}To be removed / merged with TIMESYNC. See TIMESYNC (Superseded since 2011-08)
dialect-python_array_test only.Expand description
A ping message either requesting or responding to a ping. This allows to measure the system latencies, including serial port, radio modem and UDP connections. The ping microservice is documented at https://mavlink.io/en/services/ping.html.
ID: 4
Fields
time_usec: u64To be removed / merged with TIMESYNC. See TIMESYNC (Superseded since 2011-08)
Timestamp (UNIX Epoch time or time since system boot). The receiving end can infer timestamp format (since 1.1.1970 or since system boot) by checking for the magnitude of the number.
seq: u32To be removed / merged with TIMESYNC. See TIMESYNC (Superseded since 2011-08)
PING sequence
target_system: u8To be removed / merged with TIMESYNC. See TIMESYNC (Superseded since 2011-08)
0: request ping from all receiving systems. If greater than 0: message is a ping response and number is the system id of the requesting system
target_component: u8To be removed / merged with TIMESYNC. See TIMESYNC (Superseded since 2011-08)
0: request ping from all receiving components. If greater than 0: message is a ping response and number is the component id of the requesting component.
Implementations