pub struct SYSTEM_TIME_DATA {
pub time_unix_usec: u64,
pub time_boot_ms: u32,
}Available on crate feature
dialect-python_array_test only.Expand description
The system time is the time of the sender’s master clock. This can be emitted by flight controllers, onboard computers, or other components in the MAVLink network. Components that are using a less reliable time source, such as a battery-backed real time clock, can choose to match their system clock to that of a system that indicates a more recent time. This allows more broadly accurate date stamping of logs, and so on. If precise time synchronization is needed then use TIMESYNC instead.
ID: 2
Fields
time_unix_usec: u64Timestamp (UNIX epoch time).
time_boot_ms: u32Timestamp (time since system boot).
Implementations